# WebRunner as automation framework for web testing

#### Features

* HTTP Method test
* Get response data body etc...
* Action file and executor
* result compare
* xml to json and json to xml
* Soap test
* CLI with action file

---

[![CircleCI](https://circleci.com/gh/JE-Chen/WebRunner/tree/main.svg?style=svg)](https://circleci.com/gh/JE-Chen/WebRunner/tree/main)

[![WebRunner GitHub Actions Dev](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_dev.yml/badge.svg)](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_dev.yml)

[![WebRunner GitHub Actions Stable](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_stable.yml/badge.svg)](https://github.com/JE-Chen/WebRunner/actions/workflows/webrunner-github-actions_stable.yml)

### Documentation

[![Documentation Status](https://readthedocs.org/projects/webrunner-dev/badge/?version=latest)](https://webrunner-dev.readthedocs.io/en/latest/?badge=latest)

---

## install

```
pip install je_web_runner
```

## Requires

```
python 3.7 or later
```

* Test on
    * windows 10 ~ 11
    * osx 10.5 ~ 11 big sur
    * ubuntu 20.0.4
    * raspberry pi 3B+

| All test in test dir